# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateTotpDeviceOtpAuthUrlOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'otp_auth_url': 'str',
        'name': 'str',
        'username': 'str',
        'issuer': 'str',
        'digits': 'int',
        'period': 'int',
        'algorithm': 'str'
    }

    attribute_map = {
        'otp_auth_url': 'otpAuthUrl',
        'name': 'name',
        'username': 'username',
        'issuer': 'issuer',
        'digits': 'digits',
        'period': 'period',
        'algorithm': 'algorithm'
    }

    def __init__(self, otp_auth_url=None, name=None, username=None, issuer=None, digits=6, period=30, algorithm=None, local_vars_configuration=None):  # noqa: E501
        """CreateTotpDeviceOtpAuthUrlOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._otp_auth_url = None
        self._name = None
        self._username = None
        self._issuer = None
        self._digits = None
        self._period = None
        self._algorithm = None
        self.discriminator = None

        self.otp_auth_url = otp_auth_url
        self.name = name
        self.username = username
        self.issuer = issuer
        self.digits = digits
        self.period = period
        self.algorithm = algorithm

    @property
    def otp_auth_url(self):
        """Gets the otp_auth_url of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501

        OTP Auth URI for connecting a TOTP device.  # noqa: E501

        :return: The otp_auth_url of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501
        :rtype: str
        """
        return self._otp_auth_url

    @otp_auth_url.setter
    def otp_auth_url(self, otp_auth_url):
        """Sets the otp_auth_url of this CreateTotpDeviceOtpAuthUrlOptions.

        OTP Auth URI for connecting a TOTP device.  # noqa: E501

        :param otp_auth_url: The otp_auth_url of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and otp_auth_url is None:  # noqa: E501
            raise ValueError("Invalid value for `otp_auth_url`, must not be `None`")  # noqa: E501

        self._otp_auth_url = otp_auth_url

    @property
    def name(self):
        """Gets the name of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501

        Name for labeling the TOTP device  # noqa: E501

        :return: The name of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateTotpDeviceOtpAuthUrlOptions.

        Name for labeling the TOTP device  # noqa: E501

        :param name: The name of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def username(self):
        """Gets the username of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501

        Optional username for the TOTP device  # noqa: E501

        :return: The username of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this CreateTotpDeviceOtpAuthUrlOptions.

        Optional username for the TOTP device  # noqa: E501

        :param username: The username of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def issuer(self):
        """Gets the issuer of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501

        Optional issuer override for the TOTP device  # noqa: E501

        :return: The issuer of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this CreateTotpDeviceOtpAuthUrlOptions.

        Optional issuer override for the TOTP device  # noqa: E501

        :param issuer: The issuer of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501
        :type: str
        """

        self._issuer = issuer

    @property
    def digits(self):
        """Gets the digits of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501

        Optional number of digits in TOTP code  # noqa: E501

        :return: The digits of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501
        :rtype: int
        """
        return self._digits

    @digits.setter
    def digits(self, digits):
        """Sets the digits of this CreateTotpDeviceOtpAuthUrlOptions.

        Optional number of digits in TOTP code  # noqa: E501

        :param digits: The digits of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                digits is not None and digits > 255):  # noqa: E501
            raise ValueError("Invalid value for `digits`, must be a value less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                digits is not None and digits < 0):  # noqa: E501
            raise ValueError("Invalid value for `digits`, must be a value greater than or equal to `0`")  # noqa: E501

        self._digits = digits

    @property
    def period(self):
        """Gets the period of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501

        Optional period in seconds for TOTP code expiration  # noqa: E501

        :return: The period of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this CreateTotpDeviceOtpAuthUrlOptions.

        Optional period in seconds for TOTP code expiration  # noqa: E501

        :param period: The period of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def algorithm(self):
        """Gets the algorithm of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501

        Optional algorithm override  # noqa: E501

        :return: The algorithm of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """Sets the algorithm of this CreateTotpDeviceOtpAuthUrlOptions.

        Optional algorithm override  # noqa: E501

        :param algorithm: The algorithm of this CreateTotpDeviceOtpAuthUrlOptions.  # noqa: E501
        :type: str
        """

        self._algorithm = algorithm

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateTotpDeviceOtpAuthUrlOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateTotpDeviceOtpAuthUrlOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateConnectorImapConnectionOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'imap_ssl': 'bool',
        'imap_username': 'str',
        'imap_password': 'str',
        'select_folder': 'str',
        'search_terms': 'str',
        'imap_port': 'int',
        'imap_host': 'str',
        'enabled': 'bool',
        'start_tls': 'bool',
        'proxy_enabled': 'bool',
        'proxy_port': 'int',
        'proxy_host': 'str',
        'local_host_name': 'str',
        'mechanisms': 'list[str]',
        'ssl_trust': 'str',
        'ssl_protocols': 'list[str]'
    }

    attribute_map = {
        'imap_ssl': 'imapSsl',
        'imap_username': 'imapUsername',
        'imap_password': 'imapPassword',
        'select_folder': 'selectFolder',
        'search_terms': 'searchTerms',
        'imap_port': 'imapPort',
        'imap_host': 'imapHost',
        'enabled': 'enabled',
        'start_tls': 'startTls',
        'proxy_enabled': 'proxyEnabled',
        'proxy_port': 'proxyPort',
        'proxy_host': 'proxyHost',
        'local_host_name': 'localHostName',
        'mechanisms': 'mechanisms',
        'ssl_trust': 'sslTrust',
        'ssl_protocols': 'sslProtocols'
    }

    def __init__(self, imap_ssl=None, imap_username=None, imap_password=None, select_folder=None, search_terms=None, imap_port=None, imap_host=None, enabled=None, start_tls=None, proxy_enabled=None, proxy_port=None, proxy_host=None, local_host_name=None, mechanisms=None, ssl_trust=None, ssl_protocols=None, local_vars_configuration=None):  # noqa: E501
        """CreateConnectorImapConnectionOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._imap_ssl = None
        self._imap_username = None
        self._imap_password = None
        self._select_folder = None
        self._search_terms = None
        self._imap_port = None
        self._imap_host = None
        self._enabled = None
        self._start_tls = None
        self._proxy_enabled = None
        self._proxy_port = None
        self._proxy_host = None
        self._local_host_name = None
        self._mechanisms = None
        self._ssl_trust = None
        self._ssl_protocols = None
        self.discriminator = None

        self.imap_ssl = imap_ssl
        self.imap_username = imap_username
        self.imap_password = imap_password
        self.select_folder = select_folder
        self.search_terms = search_terms
        self.imap_port = imap_port
        self.imap_host = imap_host
        self.enabled = enabled
        self.start_tls = start_tls
        self.proxy_enabled = proxy_enabled
        self.proxy_port = proxy_port
        self.proxy_host = proxy_host
        self.local_host_name = local_host_name
        self.mechanisms = mechanisms
        self.ssl_trust = ssl_trust
        self.ssl_protocols = ssl_protocols

    @property
    def imap_ssl(self):
        """Gets the imap_ssl of this CreateConnectorImapConnectionOptions.  # noqa: E501


        :return: The imap_ssl of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: bool
        """
        return self._imap_ssl

    @imap_ssl.setter
    def imap_ssl(self, imap_ssl):
        """Sets the imap_ssl of this CreateConnectorImapConnectionOptions.


        :param imap_ssl: The imap_ssl of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: bool
        """

        self._imap_ssl = imap_ssl

    @property
    def imap_username(self):
        """Gets the imap_username of this CreateConnectorImapConnectionOptions.  # noqa: E501


        :return: The imap_username of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: str
        """
        return self._imap_username

    @imap_username.setter
    def imap_username(self, imap_username):
        """Sets the imap_username of this CreateConnectorImapConnectionOptions.


        :param imap_username: The imap_username of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: str
        """

        self._imap_username = imap_username

    @property
    def imap_password(self):
        """Gets the imap_password of this CreateConnectorImapConnectionOptions.  # noqa: E501


        :return: The imap_password of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: str
        """
        return self._imap_password

    @imap_password.setter
    def imap_password(self, imap_password):
        """Sets the imap_password of this CreateConnectorImapConnectionOptions.


        :param imap_password: The imap_password of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: str
        """

        self._imap_password = imap_password

    @property
    def select_folder(self):
        """Gets the select_folder of this CreateConnectorImapConnectionOptions.  # noqa: E501

        Optional folder to select during IMAP connection  # noqa: E501

        :return: The select_folder of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: str
        """
        return self._select_folder

    @select_folder.setter
    def select_folder(self, select_folder):
        """Sets the select_folder of this CreateConnectorImapConnectionOptions.

        Optional folder to select during IMAP connection  # noqa: E501

        :param select_folder: The select_folder of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: str
        """

        self._select_folder = select_folder

    @property
    def search_terms(self):
        """Gets the search_terms of this CreateConnectorImapConnectionOptions.  # noqa: E501


        :return: The search_terms of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: str
        """
        return self._search_terms

    @search_terms.setter
    def search_terms(self, search_terms):
        """Sets the search_terms of this CreateConnectorImapConnectionOptions.


        :param search_terms: The search_terms of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: str
        """

        self._search_terms = search_terms

    @property
    def imap_port(self):
        """Gets the imap_port of this CreateConnectorImapConnectionOptions.  # noqa: E501

        IMAP server port  # noqa: E501

        :return: The imap_port of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: int
        """
        return self._imap_port

    @imap_port.setter
    def imap_port(self, imap_port):
        """Sets the imap_port of this CreateConnectorImapConnectionOptions.

        IMAP server port  # noqa: E501

        :param imap_port: The imap_port of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: int
        """

        self._imap_port = imap_port

    @property
    def imap_host(self):
        """Gets the imap_host of this CreateConnectorImapConnectionOptions.  # noqa: E501

        IMAP server host  # noqa: E501

        :return: The imap_host of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: str
        """
        return self._imap_host

    @imap_host.setter
    def imap_host(self, imap_host):
        """Sets the imap_host of this CreateConnectorImapConnectionOptions.

        IMAP server host  # noqa: E501

        :param imap_host: The imap_host of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and imap_host is None:  # noqa: E501
            raise ValueError("Invalid value for `imap_host`, must not be `None`")  # noqa: E501

        self._imap_host = imap_host

    @property
    def enabled(self):
        """Gets the enabled of this CreateConnectorImapConnectionOptions.  # noqa: E501

        IMAP server enabled  # noqa: E501

        :return: The enabled of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this CreateConnectorImapConnectionOptions.

        IMAP server enabled  # noqa: E501

        :param enabled: The enabled of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def start_tls(self):
        """Gets the start_tls of this CreateConnectorImapConnectionOptions.  # noqa: E501


        :return: The start_tls of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: bool
        """
        return self._start_tls

    @start_tls.setter
    def start_tls(self, start_tls):
        """Sets the start_tls of this CreateConnectorImapConnectionOptions.


        :param start_tls: The start_tls of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: bool
        """

        self._start_tls = start_tls

    @property
    def proxy_enabled(self):
        """Gets the proxy_enabled of this CreateConnectorImapConnectionOptions.  # noqa: E501


        :return: The proxy_enabled of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: bool
        """
        return self._proxy_enabled

    @proxy_enabled.setter
    def proxy_enabled(self, proxy_enabled):
        """Sets the proxy_enabled of this CreateConnectorImapConnectionOptions.


        :param proxy_enabled: The proxy_enabled of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: bool
        """

        self._proxy_enabled = proxy_enabled

    @property
    def proxy_port(self):
        """Gets the proxy_port of this CreateConnectorImapConnectionOptions.  # noqa: E501


        :return: The proxy_port of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: int
        """
        return self._proxy_port

    @proxy_port.setter
    def proxy_port(self, proxy_port):
        """Sets the proxy_port of this CreateConnectorImapConnectionOptions.


        :param proxy_port: The proxy_port of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: int
        """

        self._proxy_port = proxy_port

    @property
    def proxy_host(self):
        """Gets the proxy_host of this CreateConnectorImapConnectionOptions.  # noqa: E501


        :return: The proxy_host of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: str
        """
        return self._proxy_host

    @proxy_host.setter
    def proxy_host(self, proxy_host):
        """Sets the proxy_host of this CreateConnectorImapConnectionOptions.


        :param proxy_host: The proxy_host of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: str
        """

        self._proxy_host = proxy_host

    @property
    def local_host_name(self):
        """Gets the local_host_name of this CreateConnectorImapConnectionOptions.  # noqa: E501


        :return: The local_host_name of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: str
        """
        return self._local_host_name

    @local_host_name.setter
    def local_host_name(self, local_host_name):
        """Sets the local_host_name of this CreateConnectorImapConnectionOptions.


        :param local_host_name: The local_host_name of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: str
        """

        self._local_host_name = local_host_name

    @property
    def mechanisms(self):
        """Gets the mechanisms of this CreateConnectorImapConnectionOptions.  # noqa: E501

        List of IMAP mechanisms  # noqa: E501

        :return: The mechanisms of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._mechanisms

    @mechanisms.setter
    def mechanisms(self, mechanisms):
        """Sets the mechanisms of this CreateConnectorImapConnectionOptions.

        List of IMAP mechanisms  # noqa: E501

        :param mechanisms: The mechanisms of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: list[str]
        """

        self._mechanisms = mechanisms

    @property
    def ssl_trust(self):
        """Gets the ssl_trust of this CreateConnectorImapConnectionOptions.  # noqa: E501


        :return: The ssl_trust of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: str
        """
        return self._ssl_trust

    @ssl_trust.setter
    def ssl_trust(self, ssl_trust):
        """Sets the ssl_trust of this CreateConnectorImapConnectionOptions.


        :param ssl_trust: The ssl_trust of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: str
        """

        self._ssl_trust = ssl_trust

    @property
    def ssl_protocols(self):
        """Gets the ssl_protocols of this CreateConnectorImapConnectionOptions.  # noqa: E501

        List of SSL protocols  # noqa: E501

        :return: The ssl_protocols of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._ssl_protocols

    @ssl_protocols.setter
    def ssl_protocols(self, ssl_protocols):
        """Sets the ssl_protocols of this CreateConnectorImapConnectionOptions.

        List of SSL protocols  # noqa: E501

        :param ssl_protocols: The ssl_protocols of this CreateConnectorImapConnectionOptions.  # noqa: E501
        :type: list[str]
        """

        self._ssl_protocols = ssl_protocols

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateConnectorImapConnectionOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateConnectorImapConnectionOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ImportEmailOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'raw_email_base64': 'str',
        'external_id': 'str',
        'run_pipeline': 'bool',
        'override_message_id': 'bool'
    }

    attribute_map = {
        'raw_email_base64': 'rawEmailBase64',
        'external_id': 'externalId',
        'run_pipeline': 'runPipeline',
        'override_message_id': 'overrideMessageId'
    }

    def __init__(self, raw_email_base64=None, external_id=None, run_pipeline=False, override_message_id=True, local_vars_configuration=None):  # noqa: E501
        """ImportEmailOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._raw_email_base64 = None
        self._external_id = None
        self._run_pipeline = None
        self._override_message_id = None
        self.discriminator = None

        self.raw_email_base64 = raw_email_base64
        self.external_id = external_id
        self.run_pipeline = run_pipeline
        self.override_message_id = override_message_id

    @property
    def raw_email_base64(self):
        """Gets the raw_email_base64 of this ImportEmailOptions.  # noqa: E501

        Base64 encoded RFC822/MIME email contents. This should be the full raw email including headers and body, such as the bytes from an `.eml` file.  # noqa: E501

        :return: The raw_email_base64 of this ImportEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._raw_email_base64

    @raw_email_base64.setter
    def raw_email_base64(self, raw_email_base64):
        """Sets the raw_email_base64 of this ImportEmailOptions.

        Base64 encoded RFC822/MIME email contents. This should be the full raw email including headers and body, such as the bytes from an `.eml` file.  # noqa: E501

        :param raw_email_base64: The raw_email_base64 of this ImportEmailOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and raw_email_base64 is None:  # noqa: E501
            raise ValueError("Invalid value for `raw_email_base64`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                raw_email_base64 is not None and len(raw_email_base64) < 1):
            raise ValueError("Invalid value for `raw_email_base64`, length must be greater than or equal to `1`")  # noqa: E501

        self._raw_email_base64 = raw_email_base64

    @property
    def external_id(self):
        """Gets the external_id of this ImportEmailOptions.  # noqa: E501

        Optional external identifier for the imported email source. Useful for correlating imports back to another system.  # noqa: E501

        :return: The external_id of this ImportEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this ImportEmailOptions.

        Optional external identifier for the imported email source. Useful for correlating imports back to another system.  # noqa: E501

        :param external_id: The external_id of this ImportEmailOptions.  # noqa: E501
        :type: str
        """

        self._external_id = external_id

    @property
    def run_pipeline(self):
        """Gets the run_pipeline of this ImportEmailOptions.  # noqa: E501

        When true the normal inbound receive pipeline runs after persistence, including automations, webhooks, transformers, forwarders, repliers, and related fanout. When false the email is stored only.  # noqa: E501

        :return: The run_pipeline of this ImportEmailOptions.  # noqa: E501
        :rtype: bool
        """
        return self._run_pipeline

    @run_pipeline.setter
    def run_pipeline(self, run_pipeline):
        """Sets the run_pipeline of this ImportEmailOptions.

        When true the normal inbound receive pipeline runs after persistence, including automations, webhooks, transformers, forwarders, repliers, and related fanout. When false the email is stored only.  # noqa: E501

        :param run_pipeline: The run_pipeline of this ImportEmailOptions.  # noqa: E501
        :type: bool
        """

        self._run_pipeline = run_pipeline

    @property
    def override_message_id(self):
        """Gets the override_message_id of this ImportEmailOptions.  # noqa: E501

        When true MailSlurp rewrites the MIME `Message-ID` header before storing and parsing the email so imported messages do not collide with existing message identities.  # noqa: E501

        :return: The override_message_id of this ImportEmailOptions.  # noqa: E501
        :rtype: bool
        """
        return self._override_message_id

    @override_message_id.setter
    def override_message_id(self, override_message_id):
        """Sets the override_message_id of this ImportEmailOptions.

        When true MailSlurp rewrites the MIME `Message-ID` header before storing and parsing the email so imported messages do not collide with existing message identities.  # noqa: E501

        :param override_message_id: The override_message_id of this ImportEmailOptions.  # noqa: E501
        :type: bool
        """

        self._override_message_id = override_message_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImportEmailOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImportEmailOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DomainMonitorRunDueResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'trigger_source': 'str',
        'run_count': 'int',
        'requested_max_runs': 'int',
        'executed_at': 'datetime'
    }

    attribute_map = {
        'trigger_source': 'triggerSource',
        'run_count': 'runCount',
        'requested_max_runs': 'requestedMaxRuns',
        'executed_at': 'executedAt'
    }

    def __init__(self, trigger_source=None, run_count=None, requested_max_runs=None, executed_at=None, local_vars_configuration=None):  # noqa: E501
        """DomainMonitorRunDueResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._trigger_source = None
        self._run_count = None
        self._requested_max_runs = None
        self._executed_at = None
        self.discriminator = None

        self.trigger_source = trigger_source
        self.run_count = run_count
        self.requested_max_runs = requested_max_runs
        self.executed_at = executed_at

    @property
    def trigger_source(self):
        """Gets the trigger_source of this DomainMonitorRunDueResult.  # noqa: E501


        :return: The trigger_source of this DomainMonitorRunDueResult.  # noqa: E501
        :rtype: str
        """
        return self._trigger_source

    @trigger_source.setter
    def trigger_source(self, trigger_source):
        """Sets the trigger_source of this DomainMonitorRunDueResult.


        :param trigger_source: The trigger_source of this DomainMonitorRunDueResult.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and trigger_source is None:  # noqa: E501
            raise ValueError("Invalid value for `trigger_source`, must not be `None`")  # noqa: E501
        allowed_values = ["API", "USER_SCHEDULE", "CRON", "SCHEDULER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and trigger_source not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `trigger_source` ({0}), must be one of {1}"  # noqa: E501
                .format(trigger_source, allowed_values)
            )

        self._trigger_source = trigger_source

    @property
    def run_count(self):
        """Gets the run_count of this DomainMonitorRunDueResult.  # noqa: E501


        :return: The run_count of this DomainMonitorRunDueResult.  # noqa: E501
        :rtype: int
        """
        return self._run_count

    @run_count.setter
    def run_count(self, run_count):
        """Sets the run_count of this DomainMonitorRunDueResult.


        :param run_count: The run_count of this DomainMonitorRunDueResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and run_count is None:  # noqa: E501
            raise ValueError("Invalid value for `run_count`, must not be `None`")  # noqa: E501

        self._run_count = run_count

    @property
    def requested_max_runs(self):
        """Gets the requested_max_runs of this DomainMonitorRunDueResult.  # noqa: E501


        :return: The requested_max_runs of this DomainMonitorRunDueResult.  # noqa: E501
        :rtype: int
        """
        return self._requested_max_runs

    @requested_max_runs.setter
    def requested_max_runs(self, requested_max_runs):
        """Sets the requested_max_runs of this DomainMonitorRunDueResult.


        :param requested_max_runs: The requested_max_runs of this DomainMonitorRunDueResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and requested_max_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `requested_max_runs`, must not be `None`")  # noqa: E501

        self._requested_max_runs = requested_max_runs

    @property
    def executed_at(self):
        """Gets the executed_at of this DomainMonitorRunDueResult.  # noqa: E501


        :return: The executed_at of this DomainMonitorRunDueResult.  # noqa: E501
        :rtype: datetime
        """
        return self._executed_at

    @executed_at.setter
    def executed_at(self, executed_at):
        """Sets the executed_at of this DomainMonitorRunDueResult.


        :param executed_at: The executed_at of this DomainMonitorRunDueResult.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and executed_at is None:  # noqa: E501
            raise ValueError("Invalid value for `executed_at`, must not be `None`")  # noqa: E501

        self._executed_at = executed_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DomainMonitorRunDueResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DomainMonitorRunDueResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailHeaderAnalysisSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'spf': 'str',
        'dkim': 'str',
        'dmarc': 'str',
        'from_domain': 'str',
        'return_path_domain': 'str'
    }

    attribute_map = {
        'spf': 'spf',
        'dkim': 'dkim',
        'dmarc': 'dmarc',
        'from_domain': 'fromDomain',
        'return_path_domain': 'returnPathDomain'
    }

    def __init__(self, spf=None, dkim=None, dmarc=None, from_domain=None, return_path_domain=None, local_vars_configuration=None):  # noqa: E501
        """EmailHeaderAnalysisSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._spf = None
        self._dkim = None
        self._dmarc = None
        self._from_domain = None
        self._return_path_domain = None
        self.discriminator = None

        if spf is not None:
            self.spf = spf
        if dkim is not None:
            self.dkim = dkim
        if dmarc is not None:
            self.dmarc = dmarc
        if from_domain is not None:
            self.from_domain = from_domain
        if return_path_domain is not None:
            self.return_path_domain = return_path_domain

    @property
    def spf(self):
        """Gets the spf of this EmailHeaderAnalysisSummary.  # noqa: E501


        :return: The spf of this EmailHeaderAnalysisSummary.  # noqa: E501
        :rtype: str
        """
        return self._spf

    @spf.setter
    def spf(self, spf):
        """Sets the spf of this EmailHeaderAnalysisSummary.


        :param spf: The spf of this EmailHeaderAnalysisSummary.  # noqa: E501
        :type: str
        """

        self._spf = spf

    @property
    def dkim(self):
        """Gets the dkim of this EmailHeaderAnalysisSummary.  # noqa: E501


        :return: The dkim of this EmailHeaderAnalysisSummary.  # noqa: E501
        :rtype: str
        """
        return self._dkim

    @dkim.setter
    def dkim(self, dkim):
        """Sets the dkim of this EmailHeaderAnalysisSummary.


        :param dkim: The dkim of this EmailHeaderAnalysisSummary.  # noqa: E501
        :type: str
        """

        self._dkim = dkim

    @property
    def dmarc(self):
        """Gets the dmarc of this EmailHeaderAnalysisSummary.  # noqa: E501


        :return: The dmarc of this EmailHeaderAnalysisSummary.  # noqa: E501
        :rtype: str
        """
        return self._dmarc

    @dmarc.setter
    def dmarc(self, dmarc):
        """Sets the dmarc of this EmailHeaderAnalysisSummary.


        :param dmarc: The dmarc of this EmailHeaderAnalysisSummary.  # noqa: E501
        :type: str
        """

        self._dmarc = dmarc

    @property
    def from_domain(self):
        """Gets the from_domain of this EmailHeaderAnalysisSummary.  # noqa: E501


        :return: The from_domain of this EmailHeaderAnalysisSummary.  # noqa: E501
        :rtype: str
        """
        return self._from_domain

    @from_domain.setter
    def from_domain(self, from_domain):
        """Sets the from_domain of this EmailHeaderAnalysisSummary.


        :param from_domain: The from_domain of this EmailHeaderAnalysisSummary.  # noqa: E501
        :type: str
        """

        self._from_domain = from_domain

    @property
    def return_path_domain(self):
        """Gets the return_path_domain of this EmailHeaderAnalysisSummary.  # noqa: E501


        :return: The return_path_domain of this EmailHeaderAnalysisSummary.  # noqa: E501
        :rtype: str
        """
        return self._return_path_domain

    @return_path_domain.setter
    def return_path_domain(self, return_path_domain):
        """Sets the return_path_domain of this EmailHeaderAnalysisSummary.


        :param return_path_domain: The return_path_domain of this EmailHeaderAnalysisSummary.  # noqa: E501
        :type: str
        """

        self._return_path_domain = return_path_domain

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailHeaderAnalysisSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailHeaderAnalysisSummary):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.sms_controller_api import SmsControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestSmsControllerApi(unittest.TestCase):
    """SmsControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.sms_controller_api.SmsControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_sent_sms_message(self):
        """Test case for delete_sent_sms_message

        Delete sent SMS message.  # noqa: E501
        """
        pass

    def test_delete_sent_sms_messages(self):
        """Test case for delete_sent_sms_messages

        Delete all sent SMS messages  # noqa: E501
        """
        pass

    def test_delete_sms_message(self):
        """Test case for delete_sms_message

        Delete SMS message.  # noqa: E501
        """
        pass

    def test_delete_sms_messages(self):
        """Test case for delete_sms_messages

        Delete all SMS messages  # noqa: E501
        """
        pass

    def test_get_all_sms_messages(self):
        """Test case for get_all_sms_messages

        """
        pass

    def test_get_reply_for_sms_message(self):
        """Test case for get_reply_for_sms_message

        Get reply for an SMS message  # noqa: E501
        """
        pass

    def test_get_sent_sms_count(self):
        """Test case for get_sent_sms_count

        Get sent SMS count  # noqa: E501
        """
        pass

    def test_get_sent_sms_message(self):
        """Test case for get_sent_sms_message

        Get sent SMS content including body. Expects sent SMS to exist by ID.  # noqa: E501
        """
        pass

    def test_get_sent_sms_messages_paginated(self):
        """Test case for get_sent_sms_messages_paginated

        Get all SMS messages in all phone numbers in paginated form. .  # noqa: E501
        """
        pass

    def test_get_sms_codes(self):
        """Test case for get_sms_codes

        Extract verification codes from an SMS  # noqa: E501
        """
        pass

    def test_get_sms_count(self):
        """Test case for get_sms_count

        Get SMS count  # noqa: E501
        """
        pass

    def test_get_sms_message(self):
        """Test case for get_sms_message

        Get SMS content including body. Expects SMS to exist by ID. For SMS that may not have arrived yet use the WaitForController.  # noqa: E501
        """
        pass

    def test_get_unread_sms_count(self):
        """Test case for get_unread_sms_count

        Get unread SMS count  # noqa: E501
        """
        pass

    def test_mark_all_sms_as_read(self):
        """Test case for mark_all_sms_as_read

        Mark all SMS messages as read or unread  # noqa: E501
        """
        pass

    def test_mark_sms_as_read(self):
        """Test case for mark_sms_as_read

        Mark an SMS as read or unread  # noqa: E501
        """
        pass

    def test_reply_to_sms_message(self):
        """Test case for reply_to_sms_message

        Send a reply to a received SMS message. Replies are sent from the receiving number.  # noqa: E501
        """
        pass

    def test_send_sms(self):
        """Test case for send_sms

        """
        pass

    def test_set_sms_favourited(self):
        """Test case for set_sms_favourited

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneSummaryDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'phone_country_summaries': 'list[PhoneSummaryCountryDto]',
        'has_phone_numbers': 'bool',
        'has_missing_plans': 'bool',
        'total_phones': 'int',
        'plans': 'list[PlanSummaryDto]'
    }

    attribute_map = {
        'phone_country_summaries': 'phoneCountrySummaries',
        'has_phone_numbers': 'hasPhoneNumbers',
        'has_missing_plans': 'hasMissingPlans',
        'total_phones': 'totalPhones',
        'plans': 'plans'
    }

    def __init__(self, phone_country_summaries=None, has_phone_numbers=None, has_missing_plans=None, total_phones=None, plans=None, local_vars_configuration=None):  # noqa: E501
        """PhoneSummaryDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._phone_country_summaries = None
        self._has_phone_numbers = None
        self._has_missing_plans = None
        self._total_phones = None
        self._plans = None
        self.discriminator = None

        self.phone_country_summaries = phone_country_summaries
        self.has_phone_numbers = has_phone_numbers
        self.has_missing_plans = has_missing_plans
        self.total_phones = total_phones
        self.plans = plans

    @property
    def phone_country_summaries(self):
        """Gets the phone_country_summaries of this PhoneSummaryDto.  # noqa: E501


        :return: The phone_country_summaries of this PhoneSummaryDto.  # noqa: E501
        :rtype: list[PhoneSummaryCountryDto]
        """
        return self._phone_country_summaries

    @phone_country_summaries.setter
    def phone_country_summaries(self, phone_country_summaries):
        """Sets the phone_country_summaries of this PhoneSummaryDto.


        :param phone_country_summaries: The phone_country_summaries of this PhoneSummaryDto.  # noqa: E501
        :type: list[PhoneSummaryCountryDto]
        """
        if self.local_vars_configuration.client_side_validation and phone_country_summaries is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country_summaries`, must not be `None`")  # noqa: E501

        self._phone_country_summaries = phone_country_summaries

    @property
    def has_phone_numbers(self):
        """Gets the has_phone_numbers of this PhoneSummaryDto.  # noqa: E501


        :return: The has_phone_numbers of this PhoneSummaryDto.  # noqa: E501
        :rtype: bool
        """
        return self._has_phone_numbers

    @has_phone_numbers.setter
    def has_phone_numbers(self, has_phone_numbers):
        """Sets the has_phone_numbers of this PhoneSummaryDto.


        :param has_phone_numbers: The has_phone_numbers of this PhoneSummaryDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and has_phone_numbers is None:  # noqa: E501
            raise ValueError("Invalid value for `has_phone_numbers`, must not be `None`")  # noqa: E501

        self._has_phone_numbers = has_phone_numbers

    @property
    def has_missing_plans(self):
        """Gets the has_missing_plans of this PhoneSummaryDto.  # noqa: E501


        :return: The has_missing_plans of this PhoneSummaryDto.  # noqa: E501
        :rtype: bool
        """
        return self._has_missing_plans

    @has_missing_plans.setter
    def has_missing_plans(self, has_missing_plans):
        """Sets the has_missing_plans of this PhoneSummaryDto.


        :param has_missing_plans: The has_missing_plans of this PhoneSummaryDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and has_missing_plans is None:  # noqa: E501
            raise ValueError("Invalid value for `has_missing_plans`, must not be `None`")  # noqa: E501

        self._has_missing_plans = has_missing_plans

    @property
    def total_phones(self):
        """Gets the total_phones of this PhoneSummaryDto.  # noqa: E501


        :return: The total_phones of this PhoneSummaryDto.  # noqa: E501
        :rtype: int
        """
        return self._total_phones

    @total_phones.setter
    def total_phones(self, total_phones):
        """Sets the total_phones of this PhoneSummaryDto.


        :param total_phones: The total_phones of this PhoneSummaryDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_phones is None:  # noqa: E501
            raise ValueError("Invalid value for `total_phones`, must not be `None`")  # noqa: E501

        self._total_phones = total_phones

    @property
    def plans(self):
        """Gets the plans of this PhoneSummaryDto.  # noqa: E501


        :return: The plans of this PhoneSummaryDto.  # noqa: E501
        :rtype: list[PlanSummaryDto]
        """
        return self._plans

    @plans.setter
    def plans(self, plans):
        """Sets the plans of this PhoneSummaryDto.


        :param plans: The plans of this PhoneSummaryDto.  # noqa: E501
        :type: list[PlanSummaryDto]
        """
        if self.local_vars_configuration.client_side_validation and plans is None:  # noqa: E501
            raise ValueError("Invalid value for `plans`, must not be `None`")  # noqa: E501

        self._plans = plans

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneSummaryDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneSummaryDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CheckCampaignProbeResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status': 'str',
        'health_score': 'int',
        'total_checks': 'int',
        'passing_checks': 'int',
        'failing_checks': 'int',
        'checked_links': 'int',
        'checked_images': 'int',
        'link_issue_count': 'int',
        'image_issue_count': 'int',
        'compatibility_warning_count': 'int',
        'compatibility_not_supported_count': 'int',
        'compatibility_unknown_count': 'int',
        'html_error_count': 'int',
        'html_warning_count': 'int',
        'html_info_count': 'int',
        'attachment_mention_issue_count': 'int',
        'insights': 'list[str]',
        'error_message': 'str'
    }

    attribute_map = {
        'status': 'status',
        'health_score': 'healthScore',
        'total_checks': 'totalChecks',
        'passing_checks': 'passingChecks',
        'failing_checks': 'failingChecks',
        'checked_links': 'checkedLinks',
        'checked_images': 'checkedImages',
        'link_issue_count': 'linkIssueCount',
        'image_issue_count': 'imageIssueCount',
        'compatibility_warning_count': 'compatibilityWarningCount',
        'compatibility_not_supported_count': 'compatibilityNotSupportedCount',
        'compatibility_unknown_count': 'compatibilityUnknownCount',
        'html_error_count': 'htmlErrorCount',
        'html_warning_count': 'htmlWarningCount',
        'html_info_count': 'htmlInfoCount',
        'attachment_mention_issue_count': 'attachmentMentionIssueCount',
        'insights': 'insights',
        'error_message': 'errorMessage'
    }

    def __init__(self, status=None, health_score=None, total_checks=None, passing_checks=None, failing_checks=None, checked_links=None, checked_images=None, link_issue_count=None, image_issue_count=None, compatibility_warning_count=None, compatibility_not_supported_count=None, compatibility_unknown_count=None, html_error_count=None, html_warning_count=None, html_info_count=None, attachment_mention_issue_count=None, insights=None, error_message=None, local_vars_configuration=None):  # noqa: E501
        """CheckCampaignProbeResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status = None
        self._health_score = None
        self._total_checks = None
        self._passing_checks = None
        self._failing_checks = None
        self._checked_links = None
        self._checked_images = None
        self._link_issue_count = None
        self._image_issue_count = None
        self._compatibility_warning_count = None
        self._compatibility_not_supported_count = None
        self._compatibility_unknown_count = None
        self._html_error_count = None
        self._html_warning_count = None
        self._html_info_count = None
        self._attachment_mention_issue_count = None
        self._insights = None
        self._error_message = None
        self.discriminator = None

        self.status = status
        self.health_score = health_score
        self.total_checks = total_checks
        self.passing_checks = passing_checks
        self.failing_checks = failing_checks
        self.checked_links = checked_links
        self.checked_images = checked_images
        self.link_issue_count = link_issue_count
        self.image_issue_count = image_issue_count
        self.compatibility_warning_count = compatibility_warning_count
        self.compatibility_not_supported_count = compatibility_not_supported_count
        self.compatibility_unknown_count = compatibility_unknown_count
        self.html_error_count = html_error_count
        self.html_warning_count = html_warning_count
        self.html_info_count = html_info_count
        self.attachment_mention_issue_count = attachment_mention_issue_count
        self.insights = insights
        self.error_message = error_message

    @property
    def status(self):
        """Gets the status of this CheckCampaignProbeResults.  # noqa: E501


        :return: The status of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CheckCampaignProbeResults.


        :param status: The status of this CheckCampaignProbeResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["HEALTHY", "WARNING", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def health_score(self):
        """Gets the health_score of this CheckCampaignProbeResults.  # noqa: E501


        :return: The health_score of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._health_score

    @health_score.setter
    def health_score(self, health_score):
        """Sets the health_score of this CheckCampaignProbeResults.


        :param health_score: The health_score of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and health_score is None:  # noqa: E501
            raise ValueError("Invalid value for `health_score`, must not be `None`")  # noqa: E501

        self._health_score = health_score

    @property
    def total_checks(self):
        """Gets the total_checks of this CheckCampaignProbeResults.  # noqa: E501


        :return: The total_checks of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._total_checks

    @total_checks.setter
    def total_checks(self, total_checks):
        """Sets the total_checks of this CheckCampaignProbeResults.


        :param total_checks: The total_checks of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `total_checks`, must not be `None`")  # noqa: E501

        self._total_checks = total_checks

    @property
    def passing_checks(self):
        """Gets the passing_checks of this CheckCampaignProbeResults.  # noqa: E501


        :return: The passing_checks of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._passing_checks

    @passing_checks.setter
    def passing_checks(self, passing_checks):
        """Sets the passing_checks of this CheckCampaignProbeResults.


        :param passing_checks: The passing_checks of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and passing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `passing_checks`, must not be `None`")  # noqa: E501

        self._passing_checks = passing_checks

    @property
    def failing_checks(self):
        """Gets the failing_checks of this CheckCampaignProbeResults.  # noqa: E501


        :return: The failing_checks of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._failing_checks

    @failing_checks.setter
    def failing_checks(self, failing_checks):
        """Sets the failing_checks of this CheckCampaignProbeResults.


        :param failing_checks: The failing_checks of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `failing_checks`, must not be `None`")  # noqa: E501

        self._failing_checks = failing_checks

    @property
    def checked_links(self):
        """Gets the checked_links of this CheckCampaignProbeResults.  # noqa: E501


        :return: The checked_links of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._checked_links

    @checked_links.setter
    def checked_links(self, checked_links):
        """Sets the checked_links of this CheckCampaignProbeResults.


        :param checked_links: The checked_links of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and checked_links is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_links`, must not be `None`")  # noqa: E501

        self._checked_links = checked_links

    @property
    def checked_images(self):
        """Gets the checked_images of this CheckCampaignProbeResults.  # noqa: E501


        :return: The checked_images of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._checked_images

    @checked_images.setter
    def checked_images(self, checked_images):
        """Sets the checked_images of this CheckCampaignProbeResults.


        :param checked_images: The checked_images of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and checked_images is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_images`, must not be `None`")  # noqa: E501

        self._checked_images = checked_images

    @property
    def link_issue_count(self):
        """Gets the link_issue_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The link_issue_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._link_issue_count

    @link_issue_count.setter
    def link_issue_count(self, link_issue_count):
        """Sets the link_issue_count of this CheckCampaignProbeResults.


        :param link_issue_count: The link_issue_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and link_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `link_issue_count`, must not be `None`")  # noqa: E501

        self._link_issue_count = link_issue_count

    @property
    def image_issue_count(self):
        """Gets the image_issue_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The image_issue_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._image_issue_count

    @image_issue_count.setter
    def image_issue_count(self, image_issue_count):
        """Sets the image_issue_count of this CheckCampaignProbeResults.


        :param image_issue_count: The image_issue_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and image_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `image_issue_count`, must not be `None`")  # noqa: E501

        self._image_issue_count = image_issue_count

    @property
    def compatibility_warning_count(self):
        """Gets the compatibility_warning_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The compatibility_warning_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_warning_count

    @compatibility_warning_count.setter
    def compatibility_warning_count(self, compatibility_warning_count):
        """Sets the compatibility_warning_count of this CheckCampaignProbeResults.


        :param compatibility_warning_count: The compatibility_warning_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_warning_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_warning_count`, must not be `None`")  # noqa: E501

        self._compatibility_warning_count = compatibility_warning_count

    @property
    def compatibility_not_supported_count(self):
        """Gets the compatibility_not_supported_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The compatibility_not_supported_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_not_supported_count

    @compatibility_not_supported_count.setter
    def compatibility_not_supported_count(self, compatibility_not_supported_count):
        """Sets the compatibility_not_supported_count of this CheckCampaignProbeResults.


        :param compatibility_not_supported_count: The compatibility_not_supported_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_not_supported_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_not_supported_count`, must not be `None`")  # noqa: E501

        self._compatibility_not_supported_count = compatibility_not_supported_count

    @property
    def compatibility_unknown_count(self):
        """Gets the compatibility_unknown_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The compatibility_unknown_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_unknown_count

    @compatibility_unknown_count.setter
    def compatibility_unknown_count(self, compatibility_unknown_count):
        """Sets the compatibility_unknown_count of this CheckCampaignProbeResults.


        :param compatibility_unknown_count: The compatibility_unknown_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_unknown_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_unknown_count`, must not be `None`")  # noqa: E501

        self._compatibility_unknown_count = compatibility_unknown_count

    @property
    def html_error_count(self):
        """Gets the html_error_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The html_error_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._html_error_count

    @html_error_count.setter
    def html_error_count(self, html_error_count):
        """Sets the html_error_count of this CheckCampaignProbeResults.


        :param html_error_count: The html_error_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_error_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_error_count`, must not be `None`")  # noqa: E501

        self._html_error_count = html_error_count

    @property
    def html_warning_count(self):
        """Gets the html_warning_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The html_warning_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._html_warning_count

    @html_warning_count.setter
    def html_warning_count(self, html_warning_count):
        """Sets the html_warning_count of this CheckCampaignProbeResults.


        :param html_warning_count: The html_warning_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_warning_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_warning_count`, must not be `None`")  # noqa: E501

        self._html_warning_count = html_warning_count

    @property
    def html_info_count(self):
        """Gets the html_info_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The html_info_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._html_info_count

    @html_info_count.setter
    def html_info_count(self, html_info_count):
        """Sets the html_info_count of this CheckCampaignProbeResults.


        :param html_info_count: The html_info_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_info_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_info_count`, must not be `None`")  # noqa: E501

        self._html_info_count = html_info_count

    @property
    def attachment_mention_issue_count(self):
        """Gets the attachment_mention_issue_count of this CheckCampaignProbeResults.  # noqa: E501


        :return: The attachment_mention_issue_count of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: int
        """
        return self._attachment_mention_issue_count

    @attachment_mention_issue_count.setter
    def attachment_mention_issue_count(self, attachment_mention_issue_count):
        """Sets the attachment_mention_issue_count of this CheckCampaignProbeResults.


        :param attachment_mention_issue_count: The attachment_mention_issue_count of this CheckCampaignProbeResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and attachment_mention_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `attachment_mention_issue_count`, must not be `None`")  # noqa: E501

        self._attachment_mention_issue_count = attachment_mention_issue_count

    @property
    def insights(self):
        """Gets the insights of this CheckCampaignProbeResults.  # noqa: E501


        :return: The insights of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._insights

    @insights.setter
    def insights(self, insights):
        """Sets the insights of this CheckCampaignProbeResults.


        :param insights: The insights of this CheckCampaignProbeResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and insights is None:  # noqa: E501
            raise ValueError("Invalid value for `insights`, must not be `None`")  # noqa: E501

        self._insights = insights

    @property
    def error_message(self):
        """Gets the error_message of this CheckCampaignProbeResults.  # noqa: E501


        :return: The error_message of this CheckCampaignProbeResults.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this CheckCampaignProbeResults.


        :param error_message: The error_message of this CheckCampaignProbeResults.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckCampaignProbeResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CheckCampaignProbeResults):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DevicePreviewScreenshotDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'screenshot_id': 'str',
        'run_id': 'str',
        'target_id': 'str',
        'variant': 'str',
        'title': 'str',
        'description': 'str',
        'is_primary': 'bool',
        'display_order': 'int',
        'storage_key': 'str',
        'access_url': 'str',
        'live_view_url': 'str',
        'session_id': 'str',
        'browser_context_id': 'str',
        'deep_link_url': 'str',
        'width': 'int',
        'height': 'int',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'screenshot_id': 'screenshotId',
        'run_id': 'runId',
        'target_id': 'targetId',
        'variant': 'variant',
        'title': 'title',
        'description': 'description',
        'is_primary': 'isPrimary',
        'display_order': 'displayOrder',
        'storage_key': 'storageKey',
        'access_url': 'accessUrl',
        'live_view_url': 'liveViewUrl',
        'session_id': 'sessionId',
        'browser_context_id': 'browserContextId',
        'deep_link_url': 'deepLinkUrl',
        'width': 'width',
        'height': 'height',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, screenshot_id=None, run_id=None, target_id=None, variant=None, title=None, description=None, is_primary=None, display_order=None, storage_key=None, access_url=None, live_view_url=None, session_id=None, browser_context_id=None, deep_link_url=None, width=None, height=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """DevicePreviewScreenshotDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._screenshot_id = None
        self._run_id = None
        self._target_id = None
        self._variant = None
        self._title = None
        self._description = None
        self._is_primary = None
        self._display_order = None
        self._storage_key = None
        self._access_url = None
        self._live_view_url = None
        self._session_id = None
        self._browser_context_id = None
        self._deep_link_url = None
        self._width = None
        self._height = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.screenshot_id = screenshot_id
        self.run_id = run_id
        if target_id is not None:
            self.target_id = target_id
        if variant is not None:
            self.variant = variant
        if title is not None:
            self.title = title
        if description is not None:
            self.description = description
        self.is_primary = is_primary
        self.display_order = display_order
        if storage_key is not None:
            self.storage_key = storage_key
        if access_url is not None:
            self.access_url = access_url
        if live_view_url is not None:
            self.live_view_url = live_view_url
        if session_id is not None:
            self.session_id = session_id
        if browser_context_id is not None:
            self.browser_context_id = browser_context_id
        if deep_link_url is not None:
            self.deep_link_url = deep_link_url
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def screenshot_id(self):
        """Gets the screenshot_id of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The screenshot_id of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: str
        """
        return self._screenshot_id

    @screenshot_id.setter
    def screenshot_id(self, screenshot_id):
        """Sets the screenshot_id of this DevicePreviewScreenshotDto.


        :param screenshot_id: The screenshot_id of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and screenshot_id is None:  # noqa: E501
            raise ValueError("Invalid value for `screenshot_id`, must not be `None`")  # noqa: E501

        self._screenshot_id = screenshot_id

    @property
    def run_id(self):
        """Gets the run_id of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The run_id of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this DevicePreviewScreenshotDto.


        :param run_id: The run_id of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and run_id is None:  # noqa: E501
            raise ValueError("Invalid value for `run_id`, must not be `None`")  # noqa: E501

        self._run_id = run_id

    @property
    def target_id(self):
        """Gets the target_id of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The target_id of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this DevicePreviewScreenshotDto.


        :param target_id: The target_id of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: str
        """

        self._target_id = target_id

    @property
    def variant(self):
        """Gets the variant of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The variant of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: str
        """
        return self._variant

    @variant.setter
    def variant(self, variant):
        """Sets the variant of this DevicePreviewScreenshotDto.


        :param variant: The variant of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: str
        """

        self._variant = variant

    @property
    def title(self):
        """Gets the title of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The title of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this DevicePreviewScreenshotDto.


        :param title: The title of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def description(self):
        """Gets the description of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The description of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DevicePreviewScreenshotDto.


        :param description: The description of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def is_primary(self):
        """Gets the is_primary of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The is_primary of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_primary

    @is_primary.setter
    def is_primary(self, is_primary):
        """Sets the is_primary of this DevicePreviewScreenshotDto.


        :param is_primary: The is_primary of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_primary is None:  # noqa: E501
            raise ValueError("Invalid value for `is_primary`, must not be `None`")  # noqa: E501

        self._is_primary = is_primary

    @property
    def display_order(self):
        """Gets the display_order of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The display_order of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: int
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """Sets the display_order of this DevicePreviewScreenshotDto.


        :param display_order: The display_order of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and display_order is None:  # noqa: E501
            raise ValueError("Invalid value for `display_order`, must not be `None`")  # noqa: E501

        self._display_order = display_order

    @property
    def storage_key(self):
        """Gets the storage_key of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The storage_key of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: str
        """
        return self._storage_key

    @storage_key.setter
    def storage_key(self, storage_key):
        """Sets the storage_key of this DevicePreviewScreenshotDto.


        :param storage_key: The storage_key of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: str
        """

        self._storage_key = storage_key

    @property
    def access_url(self):
        """Gets the access_url of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The access_url of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: str
        """
        return self._access_url

    @access_url.setter
    def access_url(self, access_url):
        """Sets the access_url of this DevicePreviewScreenshotDto.


        :param access_url: The access_url of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: str
        """

        self._access_url = access_url

    @property
    def live_view_url(self):
        """Gets the live_view_url of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The live_view_url of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: str
        """
        return self._live_view_url

    @live_view_url.setter
    def live_view_url(self, live_view_url):
        """Sets the live_view_url of this DevicePreviewScreenshotDto.


        :param live_view_url: The live_view_url of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: str
        """

        self._live_view_url = live_view_url

    @property
    def session_id(self):
        """Gets the session_id of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The session_id of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """Sets the session_id of this DevicePreviewScreenshotDto.


        :param session_id: The session_id of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: str
        """

        self._session_id = session_id

    @property
    def browser_context_id(self):
        """Gets the browser_context_id of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The browser_context_id of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: str
        """
        return self._browser_context_id

    @browser_context_id.setter
    def browser_context_id(self, browser_context_id):
        """Sets the browser_context_id of this DevicePreviewScreenshotDto.


        :param browser_context_id: The browser_context_id of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: str
        """

        self._browser_context_id = browser_context_id

    @property
    def deep_link_url(self):
        """Gets the deep_link_url of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The deep_link_url of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: str
        """
        return self._deep_link_url

    @deep_link_url.setter
    def deep_link_url(self, deep_link_url):
        """Sets the deep_link_url of this DevicePreviewScreenshotDto.


        :param deep_link_url: The deep_link_url of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: str
        """

        self._deep_link_url = deep_link_url

    @property
    def width(self):
        """Gets the width of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The width of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this DevicePreviewScreenshotDto.


        :param width: The width of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: int
        """

        self._width = width

    @property
    def height(self):
        """Gets the height of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The height of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this DevicePreviewScreenshotDto.


        :param height: The height of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def created_at(self):
        """Gets the created_at of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The created_at of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DevicePreviewScreenshotDto.


        :param created_at: The created_at of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this DevicePreviewScreenshotDto.  # noqa: E501


        :return: The updated_at of this DevicePreviewScreenshotDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DevicePreviewScreenshotDto.


        :param updated_at: The updated_at of this DevicePreviewScreenshotDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicePreviewScreenshotDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DevicePreviewScreenshotDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class LookupBimiDomainResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'valid': 'bool',
        'query': 'DNSLookupOptions',
        'records': 'list[DNSLookupResult]',
        'errors': 'list[str]',
        'warnings': 'list[str]'
    }

    attribute_map = {
        'valid': 'valid',
        'query': 'query',
        'records': 'records',
        'errors': 'errors',
        'warnings': 'warnings'
    }

    def __init__(self, valid=None, query=None, records=None, errors=None, warnings=None, local_vars_configuration=None):  # noqa: E501
        """LookupBimiDomainResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._valid = None
        self._query = None
        self._records = None
        self._errors = None
        self._warnings = None
        self.discriminator = None

        self.valid = valid
        self.query = query
        self.records = records
        self.errors = errors
        self.warnings = warnings

    @property
    def valid(self):
        """Gets the valid of this LookupBimiDomainResults.  # noqa: E501


        :return: The valid of this LookupBimiDomainResults.  # noqa: E501
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """Sets the valid of this LookupBimiDomainResults.


        :param valid: The valid of this LookupBimiDomainResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and valid is None:  # noqa: E501
            raise ValueError("Invalid value for `valid`, must not be `None`")  # noqa: E501

        self._valid = valid

    @property
    def query(self):
        """Gets the query of this LookupBimiDomainResults.  # noqa: E501


        :return: The query of this LookupBimiDomainResults.  # noqa: E501
        :rtype: DNSLookupOptions
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this LookupBimiDomainResults.


        :param query: The query of this LookupBimiDomainResults.  # noqa: E501
        :type: DNSLookupOptions
        """
        if self.local_vars_configuration.client_side_validation and query is None:  # noqa: E501
            raise ValueError("Invalid value for `query`, must not be `None`")  # noqa: E501

        self._query = query

    @property
    def records(self):
        """Gets the records of this LookupBimiDomainResults.  # noqa: E501


        :return: The records of this LookupBimiDomainResults.  # noqa: E501
        :rtype: list[DNSLookupResult]
        """
        return self._records

    @records.setter
    def records(self, records):
        """Sets the records of this LookupBimiDomainResults.


        :param records: The records of this LookupBimiDomainResults.  # noqa: E501
        :type: list[DNSLookupResult]
        """
        if self.local_vars_configuration.client_side_validation and records is None:  # noqa: E501
            raise ValueError("Invalid value for `records`, must not be `None`")  # noqa: E501

        self._records = records

    @property
    def errors(self):
        """Gets the errors of this LookupBimiDomainResults.  # noqa: E501


        :return: The errors of this LookupBimiDomainResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this LookupBimiDomainResults.


        :param errors: The errors of this LookupBimiDomainResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    @property
    def warnings(self):
        """Gets the warnings of this LookupBimiDomainResults.  # noqa: E501


        :return: The warnings of this LookupBimiDomainResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this LookupBimiDomainResults.


        :param warnings: The warnings of this LookupBimiDomainResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LookupBimiDomainResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LookupBimiDomainResults):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhonePoolLeaseDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'pool_id': 'str',
        'phone_number_id': 'str',
        'phone_number': 'str',
        'phone_country': 'str',
        'phone_name': 'str',
        'lease_name': 'str',
        'lease_owner': 'str',
        'leased_at': 'datetime',
        'expires_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'pool_id': 'poolId',
        'phone_number_id': 'phoneNumberId',
        'phone_number': 'phoneNumber',
        'phone_country': 'phoneCountry',
        'phone_name': 'phoneName',
        'lease_name': 'leaseName',
        'lease_owner': 'leaseOwner',
        'leased_at': 'leasedAt',
        'expires_at': 'expiresAt'
    }

    def __init__(self, id=None, pool_id=None, phone_number_id=None, phone_number=None, phone_country=None, phone_name=None, lease_name=None, lease_owner=None, leased_at=None, expires_at=None, local_vars_configuration=None):  # noqa: E501
        """PhonePoolLeaseDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._pool_id = None
        self._phone_number_id = None
        self._phone_number = None
        self._phone_country = None
        self._phone_name = None
        self._lease_name = None
        self._lease_owner = None
        self._leased_at = None
        self._expires_at = None
        self.discriminator = None

        self.id = id
        self.pool_id = pool_id
        self.phone_number_id = phone_number_id
        self.phone_number = phone_number
        self.phone_country = phone_country
        if phone_name is not None:
            self.phone_name = phone_name
        if lease_name is not None:
            self.lease_name = lease_name
        if lease_owner is not None:
            self.lease_owner = lease_owner
        self.leased_at = leased_at
        if expires_at is not None:
            self.expires_at = expires_at

    @property
    def id(self):
        """Gets the id of this PhonePoolLeaseDto.  # noqa: E501


        :return: The id of this PhonePoolLeaseDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhonePoolLeaseDto.


        :param id: The id of this PhonePoolLeaseDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def pool_id(self):
        """Gets the pool_id of this PhonePoolLeaseDto.  # noqa: E501


        :return: The pool_id of this PhonePoolLeaseDto.  # noqa: E501
        :rtype: str
        """
        return self._pool_id

    @pool_id.setter
    def pool_id(self, pool_id):
        """Sets the pool_id of this PhonePoolLeaseDto.


        :param pool_id: The pool_id of this PhonePoolLeaseDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and pool_id is None:  # noqa: E501
            raise ValueError("Invalid value for `pool_id`, must not be `None`")  # noqa: E501

        self._pool_id = pool_id

    @property
    def phone_number_id(self):
        """Gets the phone_number_id of this PhonePoolLeaseDto.  # noqa: E501


        :return: The phone_number_id of this PhonePoolLeaseDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_number_id

    @phone_number_id.setter
    def phone_number_id(self, phone_number_id):
        """Sets the phone_number_id of this PhonePoolLeaseDto.


        :param phone_number_id: The phone_number_id of this PhonePoolLeaseDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number_id is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number_id`, must not be `None`")  # noqa: E501

        self._phone_number_id = phone_number_id

    @property
    def phone_number(self):
        """Gets the phone_number of this PhonePoolLeaseDto.  # noqa: E501


        :return: The phone_number of this PhonePoolLeaseDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PhonePoolLeaseDto.


        :param phone_number: The phone_number of this PhonePoolLeaseDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number`, must not be `None`")  # noqa: E501

        self._phone_number = phone_number

    @property
    def phone_country(self):
        """Gets the phone_country of this PhonePoolLeaseDto.  # noqa: E501


        :return: The phone_country of this PhonePoolLeaseDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this PhonePoolLeaseDto.


        :param phone_country: The phone_country of this PhonePoolLeaseDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def phone_name(self):
        """Gets the phone_name of this PhonePoolLeaseDto.  # noqa: E501


        :return: The phone_name of this PhonePoolLeaseDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_name

    @phone_name.setter
    def phone_name(self, phone_name):
        """Sets the phone_name of this PhonePoolLeaseDto.


        :param phone_name: The phone_name of this PhonePoolLeaseDto.  # noqa: E501
        :type: str
        """

        self._phone_name = phone_name

    @property
    def lease_name(self):
        """Gets the lease_name of this PhonePoolLeaseDto.  # noqa: E501


        :return: The lease_name of this PhonePoolLeaseDto.  # noqa: E501
        :rtype: str
        """
        return self._lease_name

    @lease_name.setter
    def lease_name(self, lease_name):
        """Sets the lease_name of this PhonePoolLeaseDto.


        :param lease_name: The lease_name of this PhonePoolLeaseDto.  # noqa: E501
        :type: str
        """

        self._lease_name = lease_name

    @property
    def lease_owner(self):
        """Gets the lease_owner of this PhonePoolLeaseDto.  # noqa: E501


        :return: The lease_owner of this PhonePoolLeaseDto.  # noqa: E501
        :rtype: str
        """
        return self._lease_owner

    @lease_owner.setter
    def lease_owner(self, lease_owner):
        """Sets the lease_owner of this PhonePoolLeaseDto.


        :param lease_owner: The lease_owner of this PhonePoolLeaseDto.  # noqa: E501
        :type: str
        """

        self._lease_owner = lease_owner

    @property
    def leased_at(self):
        """Gets the leased_at of this PhonePoolLeaseDto.  # noqa: E501


        :return: The leased_at of this PhonePoolLeaseDto.  # noqa: E501
        :rtype: datetime
        """
        return self._leased_at

    @leased_at.setter
    def leased_at(self, leased_at):
        """Sets the leased_at of this PhonePoolLeaseDto.


        :param leased_at: The leased_at of this PhonePoolLeaseDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and leased_at is None:  # noqa: E501
            raise ValueError("Invalid value for `leased_at`, must not be `None`")  # noqa: E501

        self._leased_at = leased_at

    @property
    def expires_at(self):
        """Gets the expires_at of this PhonePoolLeaseDto.  # noqa: E501


        :return: The expires_at of this PhonePoolLeaseDto.  # noqa: E501
        :rtype: datetime
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this PhonePoolLeaseDto.


        :param expires_at: The expires_at of this PhonePoolLeaseDto.  # noqa: E501
        :type: datetime
        """

        self._expires_at = expires_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhonePoolLeaseDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhonePoolLeaseDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ExtractAttachmentTextResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'present': 'bool',
        'text': 'str',
        'method_used': 'str',
        'content_type': 'str',
        'warnings': 'list[str]'
    }

    attribute_map = {
        'present': 'present',
        'text': 'text',
        'method_used': 'methodUsed',
        'content_type': 'contentType',
        'warnings': 'warnings'
    }

    def __init__(self, present=None, text=None, method_used=None, content_type=None, warnings=None, local_vars_configuration=None):  # noqa: E501
        """ExtractAttachmentTextResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._present = None
        self._text = None
        self._method_used = None
        self._content_type = None
        self._warnings = None
        self.discriminator = None

        self.present = present
        self.text = text
        self.method_used = method_used
        self.content_type = content_type
        self.warnings = warnings

    @property
    def present(self):
        """Gets the present of this ExtractAttachmentTextResult.  # noqa: E501

        True if extracted text is present  # noqa: E501

        :return: The present of this ExtractAttachmentTextResult.  # noqa: E501
        :rtype: bool
        """
        return self._present

    @present.setter
    def present(self, present):
        """Sets the present of this ExtractAttachmentTextResult.

        True if extracted text is present  # noqa: E501

        :param present: The present of this ExtractAttachmentTextResult.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and present is None:  # noqa: E501
            raise ValueError("Invalid value for `present`, must not be `None`")  # noqa: E501

        self._present = present

    @property
    def text(self):
        """Gets the text of this ExtractAttachmentTextResult.  # noqa: E501

        Extracted text when present  # noqa: E501

        :return: The text of this ExtractAttachmentTextResult.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this ExtractAttachmentTextResult.

        Extracted text when present  # noqa: E501

        :param text: The text of this ExtractAttachmentTextResult.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def method_used(self):
        """Gets the method_used of this ExtractAttachmentTextResult.  # noqa: E501

        Method for extracting text from attachments.  # noqa: E501

        :return: The method_used of this ExtractAttachmentTextResult.  # noqa: E501
        :rtype: str
        """
        return self._method_used

    @method_used.setter
    def method_used(self, method_used):
        """Sets the method_used of this ExtractAttachmentTextResult.

        Method for extracting text from attachments.  # noqa: E501

        :param method_used: The method_used of this ExtractAttachmentTextResult.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"AUTO", "NATIVE", "OCR", "LLM", "OCR_THEN_LLM"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and method_used not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `method_used` ({0}), must be one of {1}"  # noqa: E501
                .format(method_used, allowed_values)
            )

        self._method_used = method_used

    @property
    def content_type(self):
        """Gets the content_type of this ExtractAttachmentTextResult.  # noqa: E501

        Detected attachment content type  # noqa: E501

        :return: The content_type of this ExtractAttachmentTextResult.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this ExtractAttachmentTextResult.

        Detected attachment content type  # noqa: E501

        :param content_type: The content_type of this ExtractAttachmentTextResult.  # noqa: E501
        :type: str
        """

        self._content_type = content_type

    @property
    def warnings(self):
        """Gets the warnings of this ExtractAttachmentTextResult.  # noqa: E501

        Warnings or fallback notes  # noqa: E501

        :return: The warnings of this ExtractAttachmentTextResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this ExtractAttachmentTextResult.

        Warnings or fallback notes  # noqa: E501

        :param warnings: The warnings of this ExtractAttachmentTextResult.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExtractAttachmentTextResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExtractAttachmentTextResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ImapSmtpAccessServers(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'imap_server': 'ServerEndpoints',
        'secure_imap_server': 'ServerEndpoints',
        'smtp_server': 'ServerEndpoints',
        'secure_smtp_server': 'ServerEndpoints'
    }

    attribute_map = {
        'imap_server': 'imapServer',
        'secure_imap_server': 'secureImapServer',
        'smtp_server': 'smtpServer',
        'secure_smtp_server': 'secureSmtpServer'
    }

    def __init__(self, imap_server=None, secure_imap_server=None, smtp_server=None, secure_smtp_server=None, local_vars_configuration=None):  # noqa: E501
        """ImapSmtpAccessServers - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._imap_server = None
        self._secure_imap_server = None
        self._smtp_server = None
        self._secure_smtp_server = None
        self.discriminator = None

        self.imap_server = imap_server
        self.secure_imap_server = secure_imap_server
        self.smtp_server = smtp_server
        self.secure_smtp_server = secure_smtp_server

    @property
    def imap_server(self):
        """Gets the imap_server of this ImapSmtpAccessServers.  # noqa: E501


        :return: The imap_server of this ImapSmtpAccessServers.  # noqa: E501
        :rtype: ServerEndpoints
        """
        return self._imap_server

    @imap_server.setter
    def imap_server(self, imap_server):
        """Sets the imap_server of this ImapSmtpAccessServers.


        :param imap_server: The imap_server of this ImapSmtpAccessServers.  # noqa: E501
        :type: ServerEndpoints
        """
        if self.local_vars_configuration.client_side_validation and imap_server is None:  # noqa: E501
            raise ValueError("Invalid value for `imap_server`, must not be `None`")  # noqa: E501

        self._imap_server = imap_server

    @property
    def secure_imap_server(self):
        """Gets the secure_imap_server of this ImapSmtpAccessServers.  # noqa: E501


        :return: The secure_imap_server of this ImapSmtpAccessServers.  # noqa: E501
        :rtype: ServerEndpoints
        """
        return self._secure_imap_server

    @secure_imap_server.setter
    def secure_imap_server(self, secure_imap_server):
        """Sets the secure_imap_server of this ImapSmtpAccessServers.


        :param secure_imap_server: The secure_imap_server of this ImapSmtpAccessServers.  # noqa: E501
        :type: ServerEndpoints
        """
        if self.local_vars_configuration.client_side_validation and secure_imap_server is None:  # noqa: E501
            raise ValueError("Invalid value for `secure_imap_server`, must not be `None`")  # noqa: E501

        self._secure_imap_server = secure_imap_server

    @property
    def smtp_server(self):
        """Gets the smtp_server of this ImapSmtpAccessServers.  # noqa: E501


        :return: The smtp_server of this ImapSmtpAccessServers.  # noqa: E501
        :rtype: ServerEndpoints
        """
        return self._smtp_server

    @smtp_server.setter
    def smtp_server(self, smtp_server):
        """Sets the smtp_server of this ImapSmtpAccessServers.


        :param smtp_server: The smtp_server of this ImapSmtpAccessServers.  # noqa: E501
        :type: ServerEndpoints
        """
        if self.local_vars_configuration.client_side_validation and smtp_server is None:  # noqa: E501
            raise ValueError("Invalid value for `smtp_server`, must not be `None`")  # noqa: E501

        self._smtp_server = smtp_server

    @property
    def secure_smtp_server(self):
        """Gets the secure_smtp_server of this ImapSmtpAccessServers.  # noqa: E501


        :return: The secure_smtp_server of this ImapSmtpAccessServers.  # noqa: E501
        :rtype: ServerEndpoints
        """
        return self._secure_smtp_server

    @secure_smtp_server.setter
    def secure_smtp_server(self, secure_smtp_server):
        """Sets the secure_smtp_server of this ImapSmtpAccessServers.


        :param secure_smtp_server: The secure_smtp_server of this ImapSmtpAccessServers.  # noqa: E501
        :type: ServerEndpoints
        """
        if self.local_vars_configuration.client_side_validation and secure_smtp_server is None:  # noqa: E501
            raise ValueError("Invalid value for `secure_smtp_server`, must not be `None`")  # noqa: E501

        self._secure_smtp_server = secure_smtp_server

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImapSmtpAccessServers):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImapSmtpAccessServers):
            return True

        return self.to_dict() != other.to_dict()
